summaryrefslogtreecommitdiffstats
path: root/drivers/staging/android/uapi
diff options
context:
space:
mode:
authorGustavo Padovan2016-01-21 13:49:19 +0100
committerGreg Kroah-Hartman2016-02-08 02:34:58 +0100
commitd7fdb0ae9d115fa14ff3a5382c8a62de41c7786a (patch)
treee3d44633db3240a83f7194a620efe01d6b782e65 /drivers/staging/android/uapi
parentstaging/android: move SW_SYNC_USER to a debugfs file (diff)
downloadkernel-qcow2-linux-d7fdb0ae9d115fa14ff3a5382c8a62de41c7786a.tar.gz
kernel-qcow2-linux-d7fdb0ae9d115fa14ff3a5382c8a62de41c7786a.tar.xz
kernel-qcow2-linux-d7fdb0ae9d115fa14ff3a5382c8a62de41c7786a.zip
staging/android: rename sync_fence to sync_file
sync_file has a more close meaning to what a sync_fence really, a struct that represent a file that can be used by userspace to get information on a fence, or wait for it to be signaled. Signed-off-by: Gustavo Padovan <gustavo.padovan@collabora.co.uk> Reviewed-by: Maarten Lankhorst <maarten.lankhorst@linux.intel.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/android/uapi')
-rw-r--r--drivers/staging/android/uapi/sync.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/drivers/staging/android/uapi/sync.h b/drivers/staging/android/uapi/sync.h
index e964c751f6b8..73deb6907ce1 100644
--- a/drivers/staging/android/uapi/sync.h
+++ b/drivers/staging/android/uapi/sync.h
@@ -46,15 +46,15 @@ struct sync_pt_info {
};
/**
* struct sync_fence_info_data - data returned from fence info ioctl
* @len: ioctl caller writes the size of the buffer its passing in.
* ioctl returns length of sync_fence_data returned to userspace
* including pt_info.
* @name: name of fence
* @status: status of fence. 1: signaled 0:active <0:error
* @pt_info: a sync_pt_info struct for every sync_pt in the fence
*/
-struct sync_fence_info_data {
+struct sync_file_info_data {
__u32 len;
char name[32];
__s32 status;
@@ -83,15 +83,15 @@ struct sync_fence_info_data {
/**
* DOC: SYNC_IOC_FENCE_INFO - get detailed information on a fence
*
* Takes a struct sync_fence_info_data with extra space allocated for pt_info.
* Caller should write the size of the buffer into len. On return, len is
- * updated to reflect the total size of the sync_fence_info_data including
+ * updated to reflect the total size of the sync_file_info_data including
* pt_info.
*
* pt_info is a buffer containing sync_pt_infos for every sync_pt in the fence.
* To iterate over the sync_pt_infos, use the sync_pt_info.len field.
*/
#define SYNC_IOC_FENCE_INFO _IOWR(SYNC_IOC_MAGIC, 2,\
- struct sync_fence_info_data)
+ struct sync_file_info_data)
#endif /* _UAPI_LINUX_SYNC_H */
@@ -46,15 +46,15 @@ struct sync_pt_info {
};
/**
- * struct sync_fence_info_data - data returned from fence info ioctl
+ * struct sync_file_info_data - data returned from fence info ioctl
* @len: ioctl caller writes the size of the buffer its passing in.
@@ -46,15 +46,15 @@ struct sync_pt_info {
* @len: ioctl caller writes the size of the buffer its passing in.
- * ioctl returns length of sync_fence_data returned to userspace
- * including pt_info.
+ * ioctl returns length of sync_file_info_data returned to
+ * userspace including pt_info.
* @name: name of fence
* @status: status of fence. 1: signaled 0:active <0:error
@@ -83,15 +83,15 @@ struct sync_fence_info_data {
* DOC: SYNC_IOC_FENCE_INFO - get detailed information on a fence
*
- * Takes a struct sync_fence_info_data with extra space allocated for pt_info.
+ * Takes a struct sync_file_info_data with extra space allocated for pt_info.
* Caller should write the size of the buffer into len. On return, len is